@@ -1,7 +1,7 @@
 import click
 import os
 from .common import common_config, CATACOMB_URL
-from .static import DOCKERFILE, SERVER
+from .static import DOCKERFILE
 import requests
 from functools import partial
 import signal
@@ -21,8 +21,6 @@ def build():
     os.makedirs("./catacomb-out", exist_ok=True)
     with open('./catacomb-out/Dockerfile', 'w') as f:
         f.write(DOCKERFILE)
-    with open('./catacomb-out/server.py', 'w') as f:
-        f.write(SERVER)
 
     try:
         os.environ["DOCKER_BUILDKIT"] = "1"
